netapp_ontap.resources.schedule API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.schedule`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

You can use the /cluster/schedules API to view, create, and modify job schedules in a cluster.

## Retrieving a job schedule

You can retrieve job schedules by issuing a GET request to /cluster/schedules. It is also possible to retrieve a specific schedule when qualified by its UUID to /cluster/schedules/{uuid}. You can apply queries on fields to retrieve all schedules that match the combined query.

### Example

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Schedule.get_collection(type="interval")))

Try it out

    [
        Schedule(
            {
                "uuid": "08ceae53-0158-11e9-a82c-005056bb4301",
                "_links": {
                    "self": {
                        "href": "/api/cluster/schedules/08ceae53-0158-11e9-a82c-005056bb4301"
                    }
                },
                "interval": "PT10M",
                "name": "RepositoryBalanceMonitorJobSchedule",
                "type": "interval",
            }
        ),
        Schedule(
            {
                "uuid": "0941e980-0158-11e9-a82c-005056bb4301",
                "_links": {
                    "self": {
                        "href": "/api/cluster/schedules/0941e980-0158-11e9-a82c-005056bb4301"
                    }
                },
                "interval": "PT7M30S",
                "name": "Balanced Placement Model Cache Update",
                "type": "interval",
            }
        ),
        Schedule(
            {
                "uuid": "0944b975-0158-11e9-a82c-005056bb4301",
                "_links": {
                    "self": {
                        "href": "/api/cluster/schedules/0944b975-0158-11e9-a82c-005056bb4301"
                    }
                },
                "interval": "PT1H",
                "name": "Auto Balance Aggregate Scheduler",
                "type": "interval",
            }
        ),
        Schedule(
            {
                "uuid": "0c65f1fb-0158-11e9-a82c-005056bb4301",
                "_links": {
                    "self": {
                        "href": "/api/cluster/schedules/0c65f1fb-0158-11e9-a82c-005056bb4301"
                    }
                },
                "interval": "P1D",
                "name": "Application Templates ASUP Dump",
                "type": "interval",
            }
        ),
    ]

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule(uuid="25312bd8-0158-11e9-a82c-005056bb4301")
        resource.get()
        print(resource)

Try it out

    Schedule(
        {
            "uuid": "25312bd8-0158-11e9-a82c-005056bb4301",
            "cluster": {
                "uuid": "f3f9bbfa-0157-11e9-a82c-005056bb4301",
                "name": "rodan-tsundere",
            },
            "_links": {
                "self": {
                    "href": "/api/cluster/schedules/25312bd8-0158-11e9-a82c-005056bb4301"
                }
            },
            "cron": {"hours": [0], "days": [1], "minutes": [20]},
            "name": "monthly",
            "type": "cron",
        }
    )

## Creating a job schedule

You can create a job schedule by issuing a POST request to /cluster/schedules to a node in the cluster. For a successful request, the POST request returns a status code of 201. Job schedules can be of either type "cron" or type "interval". A cron schedule is run at specific minutes within the hour, or hours of the day, days of the week, days of the month, or months of the year. An interval schedule runs repeatedly at fixed intervals.

### Required fields

- name - Name of the job schedule You are required to provide a "minutes" field for a cron schedule. An "interval" field is required for an interval schedule. Do not provide both a "cron" field and an "interval" field. The schedule UUID is created by the system.

### Cron schedule fields

- cron.minutes - Minutes within the hour (0 through 59)
- cron.hours - Hours of the day (0 through 23)
- cron.weekdays - Weekdays (0 through 6, where 0 is Sunday and 6 is Saturday.)
- cron.days - Days of the month (1 through 31)
- cron.months - Months of the year (1 through 12)

### Interval schedule field

- interval - Length of time in ISO 8601 duration format.

### Examples

#### Create an interval schedule with a 1-week interval

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule()
        resource.name = "test_interval_1"
        resource.interval = "P1W"
        resource.post(hydrate=True)
        print(resource)

#### Create a cron schedule that runs daily at 12:05

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule()
        resource.name = "test_cron_1"
        resource.cron.minutes = [5]
        resource.cron.hours = [12]
        resource.post(hydrate=True)
        print(resource)

### Optional fields

By default, the schedule is owned by the local cluster. In a MetroCluster configuration, you can specify the partner cluster if the local cluster is in the switchover state.

- cluster.name - Name of the cluster owning the schedule.
- cluster.uuid - UUID of the cluster owning the schedule.

### Records field

You can create multiple schedules in one request by providing an array of named records with schedule entries. Each entry must follow the required and optional fields listed above.

## Updating a job schedule

The following fields of an existing schedule can be modified:

- cron.minutes
- cron.hours
- cron.weekdays
- cron.days
- cron.months
- interval Note that you cannot modify the name, cluster, and type of schedule. Also, you cannot modify a cron field of an interval schedule, or the interval field of a cron schedule. You can apply queries on fields to modify all schedules that match the combined query.

### Examples

#### Modify an interval schedule with a 2-day and 5-minute interval

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule(uuid="{uuid}")
        resource.interval = "P2DT5M"
        resource.patch()

#### Modify a cron schedule to run Mondays at 2

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule(uuid="{uuid}")
        resource.cron.hours = [2]
        resource.cron.weekdays = [1]
        resource.patch()

## Deleting a job schedule

You can delete job schedules based on their UUID. You can apply queries on fields to delete all schedules that match the combined query.

### Example

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule(uuid="{uuid}")
        resource.delete()

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Schedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Schedule()
        resource.delete(name="test*")

## MetroCluster configurations

In a MetroCluster configuration, user-created schedules owned by the local cluster are replicated to the partner cluster. Likewise, user-created schedules owned by the partner cluster are replicated to the local cluster. The owning cluster for a particular schedule is shown in the "cluster.name" and "cluster.uuid" fields. Normally, only schedules owned by the local cluster can be created, modified, and deleted on the local cluster. However, when a MetroCluster configuration is in switchover, the cluster in switchover state can create, modify, and delete schedules owned by the partner cluster.

## Classes

`class Schedule (*args, **kwargs)`

  Complete schedule information

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a schedule. Note that you cannot modify a cron field of an interval schedule, or the interval field of a cron schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a schedule. Note that you cannot modify a cron field of an interval schedule, or the interval field of a cron schedule.

    ### Learn more

    - `DOC /cluster/schedules`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a schedule.

    ### Required Fields

    - name - Name of the job schedule. You must provide a minutes field for a cron schedule and an interval field for an interval schedule. Do not provide both a cron field and an interval field.

    ### Learn more

    - `DOC /cluster/schedules`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class ScheduleSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Schedule object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster GET POST`

    The cluster field of the schedule.

  `cron GET POST PATCH`

    The cron field of the schedule.

  `interval GET POST PATCH`

    An ISO-8601 duration formatted string.

    Example: P1DT2H3M4S

  `links GET`

    The links field of the schedule.

  `name GET POST`

    Schedule name. Required in the URL or POST body.

  `type GET`

    Schedule type

    Valid choices:

    - cron
    - interval
  `uuid GET`

    Job schedule UUID

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412